==> intel-mediasdk_19.2.1.orig.tar.gz: MediaSDK-intel-mediasdk-19.2.1/samples/sample_hevc_fei_abr/src/sample_hevc_fei_abr.cpp <==
/******************************************************************************\
Copyright (c) 2017-2018, Intel Corporation
All rights reserved.

Redistribution and use in source and binary forms, with or without modification, are permitted provided that the following conditions are met:

1. Redistributions of source code must retain the above copyright notice, this list of conditions and the following disclaimer.

2. Redistributions in binary form must reproduce the above copyright notice, this list of conditions and the following disclaimer in the documentation and/or other materials provided with the distribution.

3. Neither the name of the copyright holder nor the names of its contributors may be used to endorse or promote products derived from this software without specific prior written permission.

THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS" AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT HOLDER OR CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.

This sample was distributed or derived from the Intel's Media Samples package.
The original version of this sample may be obtained from https://software.intel.com/en-us/intel-media-server-studio
or https://software.intel.com/en-us/media-client-solutions-support.
\**********************************************************************************/

#include "cmd_processor.h"
#include "pipeline_hevc_fei.h"

#if defined(_WIN32) || defined(_WIN64)
int _tmain(int argc, msdk_char *argv[])
#else
int main(int argc, char *argv[])
#endif
{
    sInputParams userParams;    // parameters from command line

    mfxStatus sts = MFX_ERR_NONE;

    try
    {
        CmdProcessor m_parser;
        sts = m_parser.ParseCmdLine(argc, argv);
        MSDK_CHECK_PARSE_RESULT(sts, MFX_ERR_NONE, 1);

        std::vector<sInputParams> inputParamsArray;
        while(m_parser.GetNextSessionParams(userParams))
        {
            inputParamsArray.push_back(userParams);
        }
        CFeiTranscodingPipeline pipeline(inputParamsArray);

        sts = pipeline.Init();
        MSDK_CHECK_PARSE_RESULT(sts, MFX_ERR_NONE, 1);

        pipeline.PrintInfo();

        sts = pipeline.Execute();
        MSDK_CHECK_PARSE_RESULT(sts, MFX_ERR_NONE, 1);
    }
    catch(mfxError& ex)
    {
        msdk_printf("\n%s!\n", ex.GetMessage().c_str());
        return ex.GetStatus();
    }
    catch(std::exception& ex)
    {
        msdk_printf("\nUnexpected exception!! %s\n", ex.what());
        return MFX_ERR_UNDEFINED_BEHAVIOR;
    }
    catch(...)
    {
        msdk_printf("\nUnexpected exception!!\n");
        return MFX_ERR_UNDEFINED_BEHAVIOR;
    }

    return 0;
}

==> intel-mediasdk_22.5.4.orig.tar.gz: MediaSDK-intel-mediasdk-22.5.4/samples/sample_hevc_fei_abr/src/sample_hevc_fei_abr.cpp <==
/******************************************************************************\
Copyright (c) 2017-2018, Intel Corporation
All rights reserved.

Redistribution and use in source and binary forms, with or without modification, are permitted provided that the following conditions are met:

1. Redistributions of source code must retain the above copyright notice, this list of conditions and the following disclaimer.

2. Redistributions in binary form must reproduce the above copyright notice, this list of conditions and the following disclaimer in the documentation and/or other materials provided with the distribution.

3. Neither the name of the copyright holder nor the names of its contributors may be used to endorse or promote products derived from this software without specific prior written permission.

THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS" AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT HOLDER OR CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.

This sample was distributed or derived from the Intel's Media Samples package.
The original version of this sample may be obtained from https://software.intel.com/en-us/intel-media-server-studio
or https://software.intel.com/en-us/media-client-solutions-support.
\**********************************************************************************/

#include "cmd_processor.h"
#include "pipeline_hevc_fei.h"

#if defined(_WIN32) || defined(_WIN64)
int _tmain(int argc, msdk_char *argv[])
#else
int main(int argc, char *argv[])
#endif
{
    sInputParams userParams;    // parameters from command line

    mfxStatus sts = MFX_ERR_NONE;

    try
    {
        CmdProcessor m_parser;
        sts = m_parser.ParseCmdLine(argc, argv);
        MSDK_CHECK_PARSE_RESULT(sts, MFX_ERR_NONE, 1);

        std::vector<sInputParams> inputParamsArray;
        while(m_parser.GetNextSessionParams(userParams))
        {
            inputParamsArray.push_back(userParams);
        }
        CFeiTranscodingPipeline pipeline(inputParamsArray);

        sts = pipeline.Init();
        MSDK_CHECK_PARSE_RESULT(sts, MFX_ERR_NONE, 1);

        pipeline.PrintInfo();

        sts = pipeline.Execute();
        MSDK_CHECK_PARSE_RESULT(sts, MFX_ERR_NONE, 1);
    }
    catch(mfxError& ex)
    {
        msdk_printf("\n%s!\n", ex.what());
        return ex.GetStatus();
    }
    catch(std::exception& ex)
    {
        msdk_printf("\nUnexpected exception!! %s\n", ex.what());
        return MFX_ERR_UNDEFINED_BEHAVIOR;
    }
    catch(...)
    {
        msdk_printf("\nUnexpected exception!!\n");
        return MFX_ERR_UNDEFINED_BEHAVIOR;
    }

    return 0;
}
